@@ -26,7 +26,13 @@ The hardware consisists of :
 12)2 Inverting amplifiers with gain = 47 , mainly used for microphones. 
 '''
 
-import serial, struct, math, time, commands, sys, os
+import serial, struct, math, time, commands, sys, os, glob, fnmatch
+
+import gettext
+gettext.bindtextdomain("expeyes")
+gettext.textdomain('expeyes')
+_ = gettext.gettext
+
 
 #Commands with One byte argument (41 to 80) 
 GETVERSION  =   1
@@ -95,8 +101,9 @@ AWAITFALL	= 8
 BUFSIZE     = 1800       # status + adcinfo + 1800 data
 
 #Serial devices to search for EYES hardware.  
-linux_list = ['/dev/ttyUSB0', '/dev/ttyUSB1', '/dev/ttyUSB2', '/dev/ttyUSB3', '/dev/tts/USB0','/dev/tts/USB1', \
-		'/dev/ttyACM0','/dev/ttyACM1']
+linux_list = ['/dev/ttyUSB0', '/dev/ttyUSB1', '/dev/ttyUSB2',
+	      '/dev/ttyACM0','/dev/ttyACM1','/dev/ttyACM2',
+	      '/dev/cu.usbserial']
 
 
 def open(dev = None):
@@ -107,8 +114,8 @@ def open(dev = None):
 	if obj.fd != None:
 		obj.disable_actions()
 		return obj
-	print 'Could not find Phoenix-EYES hardware'
-	print 'Check the connections.'
+	print _('Could not find Phoenix-EYES hardware')
+	print _('Check the connections.')
 
 DACMAX = 5.000				# MCP4922 DAC goes only up to 4.933 volts, in version 1
 BAUDRATE = 38400			# Serial communication
@@ -118,6 +125,7 @@ class Eyes:
 	adcsize = 1
 	m = [10.0/4095]*2 + [5.0/4095]*6 + [4095./DACMAX/2, 4095.0/DACMAX] # 8th and 9th are for DAC
 	c = [-5.0]*2 + [0.0]*6 + [4095.0/2, 0]
+	msg = '.'
 
 	def __init__(self, dev = None):
 		"""
@@ -136,24 +144,29 @@ class Eyes:
 				device_list.append(s)
 			for k in range(1,11):
 				device_list.append(k)
+		elif (os.uname()[0] == 'Darwin'):
+			device_list = []
+			device_list = glob.glob('/dev/cu.usbserial*')
 		else:
-			device_list = linux_list
+			device_list = []    # gather unused ones from the linux_list
+			for dev in linux_list:
+				res = commands.getoutput('lsof -t '+ str(dev))	
+				if res == '': 
+					device_list.append(dev)
 		
-
 		for dev in device_list:
 			try:
 				handle = serial.Serial(dev, BAUDRATE, stopbits=1, timeout = 0.3, parity=serial.PARITY_EVEN)
 			except:
 				continue
-			print 'Port %s is existing '%dev,
+			print _('Port %s is existing ')%dev,
 			if handle.isOpen() != True:
-				print 'but could not open'				
+				print _('but could not open')
 				continue
-			print 'and opened. ',
+			print _('and opened. '),
 			handle.flush()
 			time.sleep(.5)
 			while handle.inWaiting() > 0 :
-				print 'inWaiting'
 				handle.flushInput()
 			handle.write(chr(GETVERSION))
 			res = handle.read(1)
@@ -163,10 +176,10 @@ class Eyes:
 				self.fd = handle
 				self.version = ver
 				handle.timeout = 4.0	# r2rtime on .7 Hz require this
-				print 'Found EYES version ',ver
+				print _('Found EYES version '),ver
 				return 
 			else:
-				print 'No EYES hardware detected'
+				print _('No EYES hardware detected')
 				self.fd = None
 #------------------------------------------------------------------------------------
 
@@ -378,7 +391,7 @@ class Eyes:
 		self.dwrite(dat)
 		res = self.fd.read(1)
 		if res != 'D':
-			print 'eeprom write byte error = ', res
+			print _('eeprom write byte error = '), res
 
 	def eeprom_read_block(self, addr, nb):	# get nb bytes starting from addr
 		'''
@@ -391,7 +404,7 @@ class Eyes:
 		self.dwrite(chr(nb))
 		res = self.fd.read(1)
 		if res != 'D':
-			print 'eeprom read block error = ', res
+			print _('eeprom read block error = '), res
 		dat = self.fd.read(nb)
 		return dat
 
@@ -411,7 +424,7 @@ class Eyes:
 		print
 		self.m[ch] = m
 		self.c[ch] = c
-		print 'SC: ch = %d m=%10.6f  c=%10.6f'%(ch, self.m[ch], self.c[ch])
+		print _('SC: ch = %d m=%10.6f  c=%10.6f')%(ch, self.m[ch], self.c[ch])
 
 	def load_calib(self, ch):	# Load m & c from EEPROM
 		'''
@@ -419,14 +432,14 @@ class Eyes:
 		'''
 		res = self.eeprom_read_block(ch*8,8)
 		if ord(res[0]) == 255 and ord(res[1]) == 255:
-			print 'BAD Calibration data. EEPROM does not have any data '
+			print _('BAD Calibration data. EEPROM does not have any data ')
 			return
 		raw = struct.unpack('f'*2, res)
 		self.m[ch] = raw[0]
 		self.c[ch] = raw[1]
 		for c in res: print ord(c),
 		print
-		print 'LC: ch = %d m=%10.6f  c=%10.6f'%(ch, self.m[ch], self.c[ch])
+		print _('LC: ch = %d m=%10.6f  c=%10.6f')%(ch, self.m[ch], self.c[ch])
 
 	def loadall_calib(self):
 		self.load_calib(0)
@@ -442,12 +455,12 @@ class Eyes:
 		Returns the voltage at the Current Source Output.
 		'''
 		if (i < 0.020) or (i > 2.0):
-			print 'ERR:Current must be from 0.02 to 2.0 mA'
+			print _('ERR:Current must be from 0.02 to 2.0 mA')
 			return None
 		i += 0.005				# 5 uA correction is applied. NEED TO SOLVE THIS PROBLEM !!!
 		Rc = 1000.0					  # Collector Resistance from 5V reference
 		v = 5.0 - Rc * i * 1.0e-3  	  # mA to A
-		#print 'DAC0 to set current = ', v
+		#print _('DAC0 to set current = '), v
 		self.set_voltage(1,v)
 		return self.get_voltage(6)
 
@@ -463,7 +476,7 @@ class Eyes:
 		self.dwrite(chr(data>>8))
 		res = self.fd.read(1)
 		if res != 'D':
-			print 'WRITEDAC error ', res
+			print _('WRITEDAC error '), res
 			return
 		return data
 
@@ -474,7 +487,7 @@ class Eyes:
 		'''
 		if val > DACMAX: val = DACMAX		# Patch for the MCP4922 Problem 
 		if val < -DACMAX: val = -DACMAX
-		iv = int(self.m[8+ch]*val + self.c[8+ch])
+		iv = int(round(self.m[8+ch]*val + self.c[8+ch]))
 		return self.write_dac(ch,iv)
 
 	def set_bpv(self, val):		# returns the interger send to DAC
@@ -495,13 +508,13 @@ class Eyes:
 		Reads the specified ADC channel, returns a number from 0 to 4095. Low level routine.
 		'''
 		if (ch > 7):
-			print 'Argument error'
+			print _('Argument error')
 			return
 		self.dwrite(chr(READADC))
 		self.dwrite(chr(ch))
 		res = self.fd.read(1)
 		if res != 'D':
-			print 'READADC error ', res
+			print _('READADC error '), res
 			return
 		res = self.fd.read(2)
 		iv = ord(res[0]) | (ord(res[1]) << 8)
@@ -513,13 +526,13 @@ class Eyes:
 		0V to 5V for other channels.
 		'''
 		if (ch > 7):
-			print 'Argument error'
+			print _('Argument error')
 			return
 		self.dwrite(chr(READADC))
 		self.dwrite(chr(ch))
 		res = self.fd.read(1)
 		if res != 'D':
-			print 'WRITEDAC error ', res
+			print _('WRITEDAC error '), res
 			return
 		res = self.fd.read(2)
 		iv = ord(res[0]) | (ord(res[1]) << 8)
@@ -532,14 +545,14 @@ class Eyes:
 		0V to 5V for other channels. Adds the PC time info
 		'''
 		if (ch > 7):
-			print 'Argument error'
+			print _('Argument error')
 			return
 		self.dwrite(chr(READADC))
 		self.dwrite(chr(ch))
 		tm = time.time()				# Job is sent. Now mark the time
 		res = self.fd.read(1)
 		if res != 'D':
-			print 'WRITEDAC error ', res
+			print _('WRITEDAC error '), res
 			return
 		res = self.fd.read(2)
 		iv = ord(res[0]) | (ord(res[1]) << 8)
@@ -552,13 +565,13 @@ class Eyes:
 		impedance signals.
 		'''		
 		if sam > 250:
-			print 'Sampling time MUST NOT exceed 250 microseconds'
+			print _('Sampling time MUST NOT exceed 250 microseconds')
 			return
 		self.dwrite(chr(SETSAMTIME))
 		self.dwrite(chr(sam))
 		res = self.fd.read(1)
 		if res != 'D':
-			print 'SETSAMTIME ERROR ', res
+			print _('SETSAMTIME ERROR '), res
 
 	def set_adcsize(self, size):
 		'''
@@ -566,13 +579,13 @@ class Eyes:
 		4 LSBs and return the data in 1 byte, saving space and time.
 		'''
 		if size > 2:
-			print 'ADC datasize MUST be 1 or 2 bytes'
+			print _('ADC datasize MUST be 1 or 2 bytes')
 			return
 		self.dwrite(chr(SETADCSIZE))
 		self.dwrite(chr(size))
 		res = self.fd.read(1)
 		if res != 'D':
-			print 'SETADCSIZE ERROR ', res
+			print _('SETADCSIZE ERROR '), res
 		else:
 			self.adcsize = size
 
@@ -593,7 +606,7 @@ class Eyes:
 			st = time.time()
 			res = self.fd.read(1)
 			if res != 'D':
-				print 'QCAPTURE Error ', res, time.time()-st
+				print _('QCAPTURE Error '), res, time.time()-st
 				return 0,0
 			asize = 1					# adc datasize = 1 for QCAPTURE
 		else:
@@ -605,7 +618,7 @@ class Eyes:
 			self.dwrite(chr(delay>>8))
 			res = self.fd.read(1)
 			if res != 'D':
-				print 'CAPTURE error ', res
+				print _('CAPTURE error '), res
 				return
 			res = self.fd.read(1)		# adc_size info from other end
 			asize = ord(res)
@@ -613,7 +626,7 @@ class Eyes:
 		data = self.fd.read(nc)
 		dl = len(data)
 		if dl != nc:
-			print 'CAPTURE: size mismatch ', nc, dl
+			print _('CAPTURE: size mismatch '), nc, dl
 			return
 		
 		ta = []
@@ -658,7 +671,7 @@ class Eyes:
 			self.dwrite(chr(delay))
 			res = self.fd.read(1)
 			if res != 'D':
-				print 'CAPTURE01 error ', res
+				print _('CAPTURE01 error '), res
 				return		
 			asize = 1
 			tg01 =  0.009			# 0.009 milliseconds between CH0 and CH1
@@ -670,7 +683,7 @@ class Eyes:
 			self.dwrite(chr(delay>>8))
 			res = self.fd.read(1)
 			if res != 'D':
-				print 'CAPTURE01 error ', res
+				print _('CAPTURE01 error '), res
 				return
 			res = self.fd.read(1)	# adc_size info from other end
 			asize = ord(res)
@@ -680,7 +693,7 @@ class Eyes:
 		data = self.fd.read(nb)
 		dl = len(data)
 		if dl != nb:
-			print 'CAPTURE01: size mismatch ', nb, dl
+			print _('CAPTURE01: size mismatch '), nb, dl
 			return
 
 		taa = []	# time & voltage arrays for CH0
@@ -720,14 +733,14 @@ class Eyes:
 		self.dwrite(chr(delay>>8))
 		res = self.fd.read(1)
 		if res != 'D':
-			print 'CAPTURE_M32 error ', res
+			print _('CAPTURE_M32 error '), res
 			return
 		asize = 1			# datasize = 1 for CAPTURE_M32
 		nc = asize * np 	
 		data = self.fd.read(nc)
 		dl = len(data)
 		if dl != nc:
-			print 'CAPTURE_M32: size mismatch ', nc, dl
+			print _('CAPTURE_M32: size mismatch '), nc, dl
 			return
 		
 		ta = []
@@ -770,7 +783,7 @@ class Eyes:
 			mask = 0
 		else:
 			mask = 1 << pin          
-		print 'wait_rising ', AWAITRISE
+		print _('wait_rising '), AWAITRISE
 		self.dwrite(chr(SETACTION))
 		self.dwrite(chr(AWAITRISE))
 		self.dwrite(chr(mask))
@@ -797,7 +810,7 @@ class Eyes:
 			mask = 0
 		else:
 			mask = 1 << pin          
-		print 'wait_rising ', AWAITRISE
+		print _('wait_rising '), AWAITRISE
 		self.dwrite(chr(SETACTION))
 		self.dwrite(chr(AWAITFALL))
 		self.dwrite(chr(mask))
@@ -879,7 +892,7 @@ class Eyes:
 		self.dwrite(chr(USOUND))
 		res = self.fd.read(1)
 		if res != 'D':
-			print 'Echo error = ',res
+			print _('Echo error = '),res
 			return -1.0
 		res = self.fd.read(3)
 		low = (ord(res[1]) << 8) | ord(res[0])
@@ -908,7 +921,7 @@ class Eyes:
 		self.dwrite(chr(mask))
 		res = self.fd.read(1)
 		if res != 'D':
-			print 'Time Measurement call Error. CMD = ', cmd, res
+			print _('Time Measurement call Error. CMD = '), cmd, res
 			return -1.0
 		res = self.fd.read(3)
 		low = (ord(res[1]) << 8) | ord(res[0])
@@ -1024,7 +1037,7 @@ class Eyes:
 		self.dwrite(chr(DIGIN))
 		res = self.fd.read(1)
 		if res != 'D':
-			print 'DIGIN error'
+			print _('DIGIN error')
 			return
 		res = self.fd.read(1)
 		return ord(res) & 15		# 4 LSBs
